@@ -3,6 +3,8 @@ from typing import Any, Dict, List, Union
 from pydantic import BaseModel, Field
 from typing_extensions import Annotated
 
+from weaverbird.pipeline.steps.hierarchy import HierarchyStep
+
 from .steps import (
     AddMissingDatesStep,
     AddMissingDatesStepWithVariables,
@@ -26,6 +28,7 @@ from .steps import (
     DateExtractStep,
     DateExtractStepWithVariable,
     DeleteStep,
+    DissolveStep,
     DomainStep,
     DuplicateStep,
     DurationStep,
@@ -57,6 +60,7 @@ from .steps import (
     RollupStep,
     RollupStepWithVariable,
     SelectStep,
+    SimplifyStep,
     SortStep,
     SplitStep,
     SplitStepWithVariable,
@@ -94,6 +98,7 @@ PipelineStep = Annotated[
         CustomStep,
         DateExtractStep,
         DeleteStep,
+        DissolveStep,
         DomainStep,
         DuplicateStep,
         DurationStep,
@@ -103,6 +108,7 @@ PipelineStep = Annotated[
         FormulaStep,
         FromdateStep,
         FromdateStep,
+        HierarchyStep,
         IfthenelseStep,
         JoinStep,
         LowercaseStep,
@@ -114,6 +120,7 @@ PipelineStep = Annotated[
         ReplaceStep,
         RollupStep,
         SelectStep,
+        SimplifyStep,
         SortStep,
         SplitStep,
         StatisticsStep,
