@@ -1,11 +1,9 @@
-from typing import List
-
-from pydantic import Field
+from typing import List, Literal
 
 from weaverbird.pipeline.steps.utils.base import BaseStep
 from weaverbird.pipeline.types import ColumnName
 
 
 class TrimStep(BaseStep):
-    name = Field('trim', const=True)
+    name: Literal['trim'] = 'trim'
     columns: List[ColumnName]
